%global pypi_name hacking

# disable tests for now, see
# https://bugs.launchpad.net/hacking/+bug/1652409
# https://bugs.launchpad.net/hacking/+bug/1607942
# https://bugs.launchpad.net/hacking/+bug/1652411
%global with_tests 0

%if 0%{?fedora}
%global with_python3 1
%endif

%{!?upstream_version: %global upstream_version %{version}%{?milestone}}

Name:           python-%{pypi_name}
Version:        0.13.0
Release:        3%{?dist}
Summary:        OpenStack Hacking Guideline Enforcement

License:        ASL 2.0
URL:            http://github.com/openstack-dev/hacking
Source0:        https://pypi.io/packages/source/h/%{pypi_name}/%{pypi_name}-%{version}.tar.gz
# Backport two added checks from upstream (again needed for flake8 3.x
# patch to apply undiffed, and new checks are always good)
Patch0:         https://github.com/openstack-dev/hacking/commit/65b4a038eb90dba83543c77eef24042e151e8796.patch
# Backport a reversion from upstream (probably a good idea, and needed
# for next patch to apply cleanly)
Patch1:         https://github.com/openstack-dev/hacking/commit/206b421d0ab61c509c60cfb01ea7bdfdc594f314.patch
# Mostly adapt tests to work with both flake8 2.x and 3.x. Note,
# local-checks feature is entirely broken with 3.x. Will send upstream
# when I find a way to do it which doesn't involve signing my
# firstborn over to the openstack foundation
Patch2:         0001-Tests-adapt-to-flake8-3.x.patch
# Hack out the 'local-checks' feature, since it doesn't work anyway,
# to avoid the dep it introduces on pep8, and disable the test for the
# feature. Only apply on releases with flake8 3.x.
Patch3:         hacking-disable-local.patch
BuildArch:      noarch

%description
OpenStack Hacking Guideline Enforcement plugin for flake8.
%if 0%{?fedora} > 25
**NOTE**: the local-check feature is DISABLED in this package! See
https://bugs.launchpad.net/hacking/+bug/1652409 for details.
%endif # fedora > 25

%package -n python2-%{pypi_name}
Summary:        OpenStack Hacking Guideline Enforcement
%{?python_provide:%python_provide python2-%{pypi_name}}

BuildRequires:  python2-devel
BuildRequires:  python-setuptools
BuildRequires:  python-d2to1
BuildRequires:  python-pbr
BuildRequires:  python-sphinx
BuildRequires:  python-flake8
BuildRequires:  python-subunit
BuildRequires:  python-sphinx
BuildRequires:  python-testrepository
BuildRequires:  python-testscenarios
BuildRequires:  python-testtools
BuildRequires:  python-oslo-sphinx
BuildRequires:  python-six
BuildRequires:  python-flake8
BuildRequires:  pyflakes
BuildRequires:  python-mccabe
BuildRequires:  python-coverage
BuildRequires:  python-fixtures
BuildRequires:  python-mock

Requires: python-pbr
Requires: pyflakes
Requires: python-flake8
Requires: python-six

# This is required for the local-checks feature to work, it's disabled
# on F>25 for now, see above
%if 0%{?fedora} < 26
BuildRequires:  python-pep8
Requires:       python-pep8
%endif # fedora < 26

%description -n python2-%{pypi_name}
OpenStack Hacking Guideline Enforcement plugin for flake8.
%if 0%{?fedora} > 25
**NOTE**: the local-check feature is DISABLED in this package! See
https://bugs.launchpad.net/hacking/+bug/1652409 for details.
%endif # fedora > 25

%if 0%{?with_python3}
%package -n python3-%{pypi_name}
Summary:        OpenStack Hacking Guideline Enforcement
%{?python_provide:%python_provide python3-%{pypi_name}}

BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-d2to1
BuildRequires:  python3-pbr
BuildRequires:  python3-sphinx
BuildRequires:  python3-flake8
BuildRequires:  python3-subunit
BuildRequires:  python3-sphinx
BuildRequires:  python3-testrepository
BuildRequires:  python3-testscenarios
BuildRequires:  python3-testtools
BuildRequires:  python3-oslo-sphinx
BuildRequires:  python3-six
BuildRequires:  python3-flake8
BuildRequires:  python3-pyflakes
BuildRequires:  python3-mccabe

Requires: python3-pbr
Requires: python3-pyflakes
Requires: python3-flake8
Requires: python3-six
Requires: python3-pep8

# This is required for the local-checks feature to work, it's disabled
# on F>25 for now, see above
%if 0%{?fedora} < 26
BuildRequires:  python3-pep8
%endif # fedora < 26

%description  -n python3-%{pypi_name}
OpenStack Hacking Guideline Enforcement plugin for flake8.
%if 0%{?fedora} > 25
**NOTE**: the local-check feature is DISABLED in this package! See
https://bugs.launchpad.net/hacking/+bug/1652409 for details.
%endif # fedora > 25
%endif # with_python3

%prep
%setup -q -n %{pypi_name}-%{upstream_version}
# I have no idea how, but setup.cfg in the tarball has tabs instead of
# spaces. git 0.13.0 tag has spaces. wat. we need to fix this for our
# patches to apply, which means we can't use autosetup.
sed -i -e 's,\t,    ,g' setup.cfg
%patch0 -p1
%patch1 -p1
%patch2 -p1
%if 0%{?fedora} > 25
%patch3 -p1
%endif # fedora > 25

# Remove bundled egg-info
rm -rf %{pypi_name}.egg-info

# remove /usr/bin/env from core.py
sed -i '1d' hacking/core.py

# remove /usr/bin/env from tests/test_doctest.py
sed -i '1d' hacking/tests/test_doctest.py

rm -rf {test-,}requirements.txt

%build
%{__python2} setup.py build

# generate html docs
sphinx-build doc/source html
# remove the sphinx-build leftovers
rm -rf html/.{doctrees,buildinfo}

%if 0%{?with_python3}
%{__python3} setup.py build
# generate html docs
#sphinx-build doc/source html
# remove the sphinx-build leftovers
#rm -rf html/.{doctrees,buildinfo}
%endif

%install
%{__python2} setup.py install --skip-build --root %{buildroot}
%if 0%{?with_python3}
%{__python3} setup.py install --skip-build --root %{buildroot}
%endif

%check
%if 0%{?with_tests}
%{__python2} setup.py test
%if 0%{?with_python3}
rm -rf .testrepository/
%{__python3} setup.py test
%endif
%endif

%files -n python2-%{pypi_name}
%doc html README.rst
%license LICENSE
%{python2_sitelib}/*.egg-info
%{python2_sitelib}/%{pypi_name}

%if 0%{?with_python3}
%files -n python3-%{pypi_name}
%doc html README.rst
%license LICENSE
%{python3_sitelib}/*.egg-info
%{python3_sitelib}/%{pypi_name}
%endif

%changelog
* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.13.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Mon Feb 20 2017 Matthias Runge <mrunge@redhat.com> - 0.13.0-2
- disable tests for now (see above for links to bugs)

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.13.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Dec 22 2016 Adam Williamson <awilliam@redhat.com> - 0.13.0-1
- Update to 0.13.0 (some fixes for flake8 3.x compat from upstream)
- Patch test suite to be compatible with flake8 2.x and 3.x
- Disable 'local-check' feature on >F25 (incompatible with flake8 3.x)
- Re-enable Python 3 tests (they seem to work again now)

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 0.10.2-5
- Rebuild for Python 3.6

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10.2-4
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.10.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Nov 10 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10.2-2
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Tue Sep 01 2015 Lukas Bezdicka <lbezdick@redhat.com> - 0.10.2-1
- Add python3 sub package and update to 0.10.2

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Mar 03 2015 Matthias Runge <mrunge@redhat.com> - 0.10.1-1
- update to 0.10.1

* Mon Oct 20 2014 Matthias Runge <mrunge@redhat.com> - 0.9.2-1
- udapte to 0.9.2

* Tue Jun 10 2014 Matthias Runge <mrunge@redhat.com> - 0.9.1-1
- update to 0.9.1

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri Mar 28 2014 Matthias Runge <mrunge@redhat.com> - 0.8.1-1
- update to 0.8.1

* Tue Nov 19 2013 Matthias Runge <mrunge@redhat.com> - 0.8.0-1
- update to 0.8.0

* Tue Sep 17 2013 Matthias Runge <mrunge@redhat.com> - 0.7.2-1
- update to 0.7.2

* Fri Jun 07 2013 Matthias Runge <mrunge@redhat.com> - 0.5.3-2
- also use checks and move requirements to rpm-requiremens

* Mon Apr 29 2013 Matthias Runge <mrunge@redhat.com> - 0.5.3-1
- Initial package.
